@@ -1,5 +1,5 @@
 /*
- * $Id: browser.c,v 1.16 1998/05/25 22:06:45 jochen Exp $
+ * $Id: browser.c,v 1.18 1998/07/04 15:58:37 gregm Exp $
  * GXSNMP - An snmp managment application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -24,29 +24,31 @@ static char const copyright[] =
 "@(#) Copyright (C) 1998 Gregory McLean";
 #endif
 static char const rcsid[] =
-"$Id: browser.c,v 1.16 1998/05/25 22:06:45 jochen Exp $";
+"$Id: browser.c,v 1.18 1998/07/04 15:58:37 gregm Exp $";
 
 #include "main.h"
 
-static void create_browser_panel    (void);
-static void build_mib_tree          (void);
-static void fill_combo_list         (void);
-static void combo_foreach_func      (void *key, void *val, void *data);
-static void close_browser_cb        (GtkWidget   *widget,
-				     gpointer    data);
-static void first_button_cb         (GtkWidget   *widget,
-				     gpointer    data);
-static void next_button_cb          (GtkWidget   *widget,
-				     gpointer    data);
-static void get_button_cb           (GtkWidget   *widget,
-				     gpointer    data);
-static void put_button_cb           (GtkWidget   *widget,
-				     gpointer    data);
-static gint panel_delete_cb         (GtkWidget   *widget,
-				     GdkEvent    *e,
-				     gpointer    data);
-static void cb_tree_changed         (GtkTree     *tree);
-static void refresh_mib_tree        (hosts       *host);
+static void       create_browser_panel          (void);
+static void       build_mib_tree                (void);
+static void       fill_combo_list               (void);
+static void       combo_foreach_func            (void        *key, 
+						 void        *val, 
+						 void        *data);
+static void       close_browser_cb              (GtkWidget   *widget,
+						 gpointer    data);
+static void       first_button_cb               (GtkWidget   *widget,
+						 gpointer    data);
+static void       next_button_cb                (GtkWidget   *widget,
+						 gpointer    data);
+static void       get_button_cb                 (GtkWidget   *widget,
+						 gpointer    data);
+static void       put_button_cb                 (GtkWidget   *widget,
+						 gpointer    data);
+static gint       panel_delete_cb               (GtkWidget   *widget,
+						 GdkEvent    *e,
+						 gpointer    data);
+static void       cb_tree_changed               (GtkTree     *tree);
+static void       refresh_mib_tree              (hosts       *host);
 
 extern gxsnmp *app_info;
 static GList  *cbitems = NULL;
@@ -213,11 +215,7 @@ cb_tree_changed(GtkTree* tree)
     }
   gtk_entry_set_text (GTK_ENTRY (app_info->brows_panel->mib_type), buffer);
   getoid (snmptree, oidbuf);
-#ifdef UCD_SNMP
-  buffer = module_name(snmptree->modid);
-  if (!buffer) buffer="";
-  gtk_entry_set_text (GTK_ENTRY (app_info->brows_panel->mib_group), buffer);
-#endif
+
   gtk_entry_set_text (GTK_ENTRY (app_info->brows_panel->mib_oid), oidbuf);
   getlabel (snmptree, oidbuf);
   gtk_entry_set_text (GTK_ENTRY (app_info->brows_panel->mib_label), oidbuf);
@@ -305,11 +303,11 @@ create_browser_panel ()
   GtkWidget    *table;
   GtkWidget    *scrolled_window;
   GtkWidget    *button_box;
+  GtkWidget    *pixmap;
   GtkWidget    *bar;
   GtkWidget    *button;
   hosts        *host;
 
-  
   app_info->brows_panel = (browser_panel *)g_malloc (sizeof (browser_panel));
   app_info->brows_panel->window = new_window (_("GXSNMP: Mib Browser"),
 					      GTK_WINDOW_TOPLEVEL,
@@ -343,11 +341,7 @@ create_browser_panel ()
   frame = gtk_frame_new (NULL);
   gtk_box_pack_start (GTK_BOX (right_box), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
-#ifdef UCD_SNMP
-  table = gtk_table_new ( 6, 2, FALSE);
-#else
   table = gtk_table_new ( 5, 2, FALSE);
-#endif
   gtk_container_add (GTK_CONTAINER (frame), table);
   label = gtk_label_new (_("Object Type"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
@@ -398,7 +392,6 @@ create_browser_panel ()
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
   gtk_widget_show (label);
   app_info->brows_panel->mib_host = gtk_combo_new ();
-  g_print ("Checking host hash\n");
   if (app_info->host_hash == NULL)
     {
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO 
@@ -415,20 +408,7 @@ create_browser_panel ()
 		    1, 2, 4, 5,
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
   gtk_widget_show (app_info->brows_panel->mib_host);
-#ifdef UCD_SNMP
-  label = gtk_label_new ("Group");
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6,
-                    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (label);
-  app_info->brows_panel->mib_group = gtk_entry_new ();
-  gtk_entry_set_editable (GTK_ENTRY (app_info->brows_panel->mib_group), FALSE)
-;
-  gtk_table_attach (GTK_TABLE (table), app_info->brows_panel->mib_group,
-                  1, 2, 5, 6,
-                  GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (app_info->brows_panel->mib_group);
-#endif
+
   gtk_widget_show (table);
 
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
@@ -548,7 +528,10 @@ create_browser_panel ()
 		      NULL);
   gtk_container_add (GTK_CONTAINER (button_box), button);
   gtk_widget_show (button);
-  app_info->brows_panel->rbutton = gtk_button_new_with_label (_("Refresh"));
+  pixmap = gnome_stock_pixmap_widget (app_info->brows_panel->window, 
+				      GNOME_STOCK_PIXMAP_REFRESH);
+  app_info->brows_panel->rbutton = gnome_pixmap_button (pixmap,
+							      _("Refresh"));
   gtk_signal_connect (GTK_OBJECT (app_info->brows_panel->rbutton), "clicked",
 		      GTK_SIGNAL_FUNC (refresh_mib_tree),
 		      NULL);
