@@ -1,5 +1,5 @@
 /*
- * $Id: config_panel.c,v 1.20 1998/05/26 21:36:42 jochen Exp $
+ * $Id: config_panel.c,v 1.21 1998/07/04 15:58:38 gregm Exp $
  * GXSNMP -- An snmp management application.
  * Copyright (C) 1998 Gregory Mclean
  *
@@ -24,7 +24,7 @@ static char const copyright[] =
 "@(#) Copyright (c) 1998 Gregory McLean";
 #endif
 static char const rcsid[] = 
- "$Id: config_panel.c,v 1.20 1998/05/26 21:36:42 jochen Exp $";
+ "$Id: config_panel.c,v 1.21 1998/07/04 15:58:38 gregm Exp $";
 
 #include <string.h>
 #include <gtk/gtk.h>
@@ -89,17 +89,18 @@ static GnomeUIInfo config_menu[] = {
 /*
  * local functions
  */
-static void             create_config_panel (void);
-static void             ok_button_cb        (GtkWidget       *widget,
-			                     gpointer        data);
-static void             cancel_button_cb    (GtkWidget       *widget,
-					     gpointer        data);
-static void             save_button_cb      (GtkWidget       *widget,
-					     gpointer        data);
-static gint             panel_delete_cb     (GtkWidget       *widget,
-					     GdkEvent        *e,
-					     gpointer        data);
-static GtkMenuFactory   *create_menu        (void);
+static void             create_config_panel       (void);
+static void             ok_button_cb              (GtkWidget       *widget,
+						   gpointer        data);
+static void             cancel_button_cb          (GtkWidget       *widget,
+						   gpointer        data);
+static void             save_button_cb            (GtkWidget       *widget,
+						   gpointer        data);
+static gint             panel_delete_cb           (GtkWidget       *widget,
+						   GdkEvent        *e,
+						   gpointer        data);
+static void             color_changed_cb          (GnomeColorSelector *widget,
+						   gchar              **color);
 
 /*
  * global functions
@@ -107,16 +108,19 @@ static GtkMenuFactory   *create_menu        (void);
 static void
 create_config_panel ()
 {
-  GtkWidget      *button;
-  GtkWidget      *vbox;
-  GtkWidget      *notebook;
-  GtkWidget      *label;
-  GtkWidget      *table;
-  GtkWidget      *scrolled;
-  GtkWidget      *bar;
-  GtkWidget      *button_box;
-  GtkWidget      *frame;
-  GtkAdjustment  *adjustment;
+  GtkWidget           *button;
+  GtkWidget           *vbox;
+  GtkWidget           *notebook;
+  GtkWidget           *label;
+  GtkWidget           *table;
+  GtkWidget           *scrolled;
+  GtkWidget           *bar;
+  GtkWidget           *button_box;
+  GtkWidget           *frame;
+  GtkAdjustment       *adjustment;
+  GnomeColorSelector  *colorsel;
+  GtkWidget           *colbutton;
+  gchar               *dummy;
   GtkMenuFactory *mf;
   char           buf[20];
   int            i;
@@ -280,7 +284,16 @@ create_config_panel ()
    * General configuration page
    */
   frame = gtk_frame_new (NULL);
-  gtk_widget_show (frame);
+  table = gtk_table_new (2, 4, FALSE);
+  gtk_container_add (GTK_CONTAINER (frame), table);
+  colorsel = gnome_color_selector_new ( (SetColorFunc)color_changed_cb,
+					&dummy);
+  colbutton = gnome_color_selector_get_button (colorsel);
+  gtk_table_attach (GTK_TABLE (table), colbutton, 0, 1, 0, 1,
+		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 1);
+  button = gtk_check_button_new_with_label (_("Enable tooltips"));
+  gtk_table_attach (GTK_TABLE (table), button, 0, 1, 1, 2,
+		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 1);
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame,
 			    notebook_tab (_("General")));
 
@@ -366,31 +379,28 @@ create_config_panel ()
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (button_box), 2);
   gtk_button_box_set_child_size (GTK_BUTTON_BOX (button_box), 85, 20);
   gtk_box_pack_start (GTK_BOX (vbox), button_box, FALSE, FALSE, 0);
-  gtk_widget_show (button_box);
+
 
   button = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       GTK_SIGNAL_FUNC (ok_button_cb),
                       NULL);
   gtk_container_add (GTK_CONTAINER (button_box), button);
-  gtk_widget_show (button);
+
   button = gnome_stock_button (GNOME_STOCK_BUTTON_CANCEL);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
                       GTK_SIGNAL_FUNC (cancel_button_cb),
                       NULL);
   gtk_container_add (GTK_CONTAINER (button_box), button);
-  gtk_widget_show (button);
 
   button = gtk_button_new_with_label (_("Defaults"));
   gtk_container_add (GTK_CONTAINER (button_box), button);
-  gtk_widget_show (button);
 
   button = gtk_button_new_with_label (_("Save"));
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      GTK_SIGNAL_FUNC (save_button_cb),
 		      NULL);
   gtk_container_add (GTK_CONTAINER (button_box), button);
-  gtk_widget_show (button);
   /* 
    * Put all this gibbeirsh in the gnome app window
    */
@@ -413,6 +423,11 @@ open_config_panel ()
       gtk_widget_show (app_info->conf_panel->window);
 }
 
+static void
+color_changed_cb (GnomeColorSelector *widget, gchar **color)
+{
+}
+
 static void
 ok_button_cb (GtkWidget *widget,
               gpointer  data)
@@ -555,17 +570,6 @@ panel_delete_cb (GtkWidget *widget,
 /*
  * Local helper functions 
  */
-static GtkMenuFactory *
-create_menu ()
-{
-  GtkMenuFactory  *subfactory;
-  int             i;
-
-  subfactory = gtk_menu_factory_new (GTK_MENU_FACTORY_MENU_BAR);
-  gtk_menu_factory_add_entries (subfactory, config_menu, ELEMENTS 
-				(config_menu));
-  return subfactory;
-}
 
 /*
  * Global standard panel functions
