@@ -1,5 +1,5 @@
 /*
- * $Id: main.c,v 1.38 1998/05/31 01:41:34 gregm Exp $
+ * $Id: main.c,v 1.46 1998/08/01 20:04:28 gregm Exp $
  * GXSNMP -- An snmp mangament application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -25,7 +25,7 @@ static char const copyright[] =
 "@(#) Copyright (c) 1998 Gregory McLean";
 #endif
 static char const rcsid[] =
- "$Id: main.c,v 1.38 1998/05/31 01:41:34 gregm Exp $";
+ "$Id: main.c,v 1.46 1998/08/01 20:04:28 gregm Exp $";
 #include <config.h>
 #include "main.h"
 #include <gtkhost.h>
@@ -184,14 +184,24 @@ generate_menu (gchar *name, MyMenu *mymenu, int count, GtkWidget *window,
 	{
 	  tmp = mymenu[x].accel;
 	  gtk_menu_factory_parse_accelerator ( tmp, &accel_key, &accel_mods);
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	  gtk_widget_add_accelerator (item, "activate", app_info->accel_table,
+				      accel_key, accel_mods, 
+				      GTK_ACCEL_VISIBLE);
+#else
 	  gtk_widget_install_accelerator (item,
 					  app_info->accel_table,
 					  "activate",
 					  accel_key,
 					  accel_mods);
+#endif
 	}
     }
+#ifdef GTK_HAVE_FEATURES_1_1_0
+  gtk_menu_set_accel_group (GTK_MENU (menu), app_info->accel_table);
+#else
   gtk_menu_set_accelerator_table (GTK_MENU (menu), app_info->accel_table);
+#endif
   return root;
 }
 
@@ -205,15 +215,15 @@ make_toolbar (GtkWidget *window)
     gtk_widget_realize (window);
 
   toolbar = gtk_toolbar_new (GTK_ORIENTATION_VERTICAL, GTK_TOOLBAR_BOTH);
-  
-  kludge = gnome_unconditional_pixmap_file ("desktop.xpm");
+
+  kludge = gnome_unconditional_pixmap_file ("add_host.xpm");
   gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
 			   _("Add host"), _("Add a new host to the database"), 
 			   NULL,
 			   new_pixmap (kludge, window->window, 
 				       &window->style->bg[GTK_STATE_NORMAL]),
 			   (GtkSignalFunc) open_add_host_panel, NULL);
-  kludge = gnome_unconditional_pixmap_file ("host_del.xpm");
+  kludge = gnome_unconditional_pixmap_file ("del_host.xpm");
   gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
 			   _("Delete host"), 
                            _("Remove a host from the database"),
@@ -258,6 +268,7 @@ make_toolbar (GtkWidget *window)
                            gnome_stock_pixmap_widget (window, 
                                                       GNOME_STOCK_PIXMAP_QUIT),
 			   (GtkSignalFunc) quit_button_cb, NULL);
+
   return toolbar;
 }
 GtkWidget *scrolled;
@@ -300,8 +311,12 @@ create_main_panel ()
     gtk_widget_show (hbox);
 
     menubar = gtk_menu_bar_new ();
+#ifdef GTK_HAVE_FEATURES_1_1_0
+    app_info->accel_table = gtk_accel_group_new ();
+#else
     app_info->accel_table = gtk_accelerator_table_new ();
     gtk_accelerator_table_ref (app_info->accel_table);
+#endif
 
     gtk_container_add (GTK_CONTAINER (hbox), menubar);
     gtk_widget_show (menubar);
@@ -405,10 +420,15 @@ create_main_panel ()
 			      GTK_STATUSBAR(app_info->mouse_stat),
 			      "mouse_stat");
     gtk_box_pack_start (GTK_BOX (vbox), app_info->app_stat, FALSE, FALSE, 0);
-    gtk_widget_show (app_info->app_stat);
+#ifdef GTK_HAVE_FEATURES_1_1_0
+    gtk_window_add_accel_group (GTK_WINDOW (app_info->window),
+				app_info->accel_table);
+#else
     gtk_window_add_accelerator_table (GTK_WINDOW (app_info->window),
 				      app_info->accel_table);
-    gtk_widget_show (app_info->window);
+#endif
+    g_print ("Showing map window...\n");
+    gtk_widget_show_all (app_info->window);
     init_pixmap_d (app_info->app_stat);
 }
 
@@ -466,6 +486,9 @@ delete_host_cb (GtkWidget *widget, gpointer  data)
 {
   hosts   *entry;
 
+#ifdef HAVE_SQL
+  sql_server    *sql_serv;
+#endif
   if (app_info->current_host == NULL)
     {
       update_app_stat (_("No host selected to delete."));
@@ -478,6 +501,17 @@ delete_host_cb (GtkWidget *widget, gpointer  data)
 					    (app_info->current_host), 
 					    "host_entry");
       hl_del_host (entry);
+      printf("About to do it...\n");
+      app_info->host_count--;
+      update_known_hosts (app_info->host_count);
+#ifdef HAVE_SQL
+      sql_serv = g_new (sql_server, 1);
+      sql_serv->sql_host = g_strdup (app_info->current_config.def_sql_host);
+      sql_serv->sql_user = g_strdup (app_info->current_config.def_sql_user);
+      sql_serv->sql_pass = g_strdup (app_info->current_config.def_sql_pass);
+      sql_del_host_entry (sql_serv, entry);
+      g_free (sql_serv);
+#endif
     }
 }
 static gint
@@ -677,6 +711,8 @@ app_init()
   app_info->host_hash   = NULL;
   app_info->host_count  = 0;
   app_info->network_count = 0;
+  app_info->root_width  = gdk_screen_width ();
+  app_info->root_height = gdk_screen_height ();
 }
 
 /*
@@ -699,9 +735,11 @@ main (int argc, char *argv[])
   gnome_init ("gxsnmp", NULL, argc, argv, 0, NULL);
   entry = getpwuid (getuid());
   app_init ();
+#ifndef GTK_HAVE_FEATURES_1_1_0
   gtk_accelerator_table_set_mod_mask (NULL, GDK_SHIFT_MASK |
 				      GDK_CONTROL_MASK |
 				      GDK_MOD1_MASK);
+#endif
   event.category     = GX_EVENT_INFO;
   event.sub_category = GX_INFO_NONE;
   event.timestamp    = time (NULL);
@@ -712,6 +750,8 @@ main (int argc, char *argv[])
   g_print ("Pid: [%d]\n",getpid());
 #endif
   init_mib();
+  snmpinit ();
+  
   if (getuid() != 0)
     {
       /*
@@ -743,7 +783,6 @@ main (int argc, char *argv[])
 
   create_host_popup ( (GtkWindow *)app_info->window);
   
-  snmpinit ();
   time_id = gtk_timeout_add (1000, run_queue, NULL);
  
   gtk_main();
