@@ -1,5 +1,5 @@
 /*
- * $Id: snmp_host.c,v 1.21 1998/05/21 20:40:14 gregm Exp $
+ * $Id: snmp_host.c,v 1.24 1998/07/29 21:18:50 jochen Exp $
  * GXSNMP -- An snmp management application.
  * Copyright (C) 1998 Gregory McLean
  *
@@ -24,7 +24,7 @@ static char const copyright[] =
 "@(#) Copyright (c) 1998 Gregory McLean";
 #endif
 static char const rcsid[] =
- "$Id: snmp_host.c,v 1.21 1998/05/21 20:40:14 gregm Exp $";
+ "$Id: snmp_host.c,v 1.24 1998/07/29 21:18:50 jochen Exp $";
 
 #include <string.h>
 #include <sys/types.h>
@@ -237,6 +237,9 @@ edit_ok_button_cb (GtkWidget *widget, gpointer data)
   int   i;
   char  buf[512];
   hosts *host;
+#ifdef HAVE_SQL
+  sql_server    *sql_serv;
+#endif
 
   host = get_current_host();
   if (host)
@@ -286,6 +289,14 @@ edit_ok_button_cb (GtkWidget *widget, gpointer data)
 	      break;
 	    }
 	}
+#ifdef HAVE_SQL
+      sql_serv = g_new (sql_server, 1);
+      sql_serv->sql_host = g_strdup (app_info->current_config.def_sql_host);
+      sql_serv->sql_user = g_strdup (app_info->current_config.def_sql_user);
+      sql_serv->sql_pass = g_strdup (app_info->current_config.def_sql_pass);
+      sql_update_host_entry (sql_serv, host);
+      g_free (sql_serv);
+#endif
     }
   hide_edit_panel ();
 }
@@ -682,6 +693,9 @@ add_host_ok_cb (GtkWidget *widget, gpointer data)
 	}
     }
 
+  /* FIXME: Transport domain should be configurable */
+  hentry->hl_snmp.domain = AF_INET;
+
   hentry->hl_location.x = 10;
   hentry->hl_location.y = 10;
   hentry->hl_location.width = 80;
@@ -689,7 +703,6 @@ add_host_ok_cb (GtkWidget *widget, gpointer data)
   
   if (!(g_hash_table_lookup (app_info->host_hash, hentry->hl_snmp.name)))
     {
-      add_host (hentry);
 #ifdef HAVE_SQL
       sql_serv = g_new (sql_server, 1);
       sql_serv->sql_host = g_strdup (app_info->current_config.def_sql_host);
@@ -698,6 +711,7 @@ add_host_ok_cb (GtkWidget *widget, gpointer data)
       sql_add_host_entry (sql_serv, hentry);
       g_free (sql_serv);
 #endif
+      add_host (hentry);
     }
   else
     {
@@ -923,6 +937,86 @@ static set_panel *get_panel = NULL;
 static void
 create_get_panel ()
 {
+  GtkWidget *frame1;
+  GtkWidget *table1;
+  GtkWidget *hseparator1;
+  GtkWidget *entry2;
+  GtkWidget *label3;
+  GtkWidget *frame2;
+  GtkWidget *hbuttonbox1;
+  GtkWidget *button1;
+  GtkWidget *button2;
+  GtkWidget *button3;
+  GtkWidget *entry1;
+  GtkWidget *combo1;
+  GtkWidget *label;
+
+  get_panel = (set_panel *)g_malloc (sizeof (set_panel));
+
+  get_panel->window = gnome_app_new ("GXSNMP", N_("Get A Mib"));
+  gtk_window_set_wmclass (GTK_WINDOW (get_panel->window), "mib_get_panel",
+			  "GXSNMP");
+
+  gtk_signal_connect (GTK_OBJECT (get_panel->window), "delete_event",
+		      GTK_SIGNAL_FUNC (delete_get_panel),
+		      get_panel->window);
+  frame1 = gtk_frame_new(NULL);
+
+  gtk_container_border_width(GTK_CONTAINER(frame1), 4);
+
+  table1 = gtk_table_new(5, 4, FALSE);
+  gtk_container_add(GTK_CONTAINER(frame1), table1);
+
+  label = gtk_label_new (N_("Mib "));
+  gtk_table_attach (GTK_TABLE(table1), label, 0, 1, 0, 1,
+                   GTK_FILL, GTK_FILL, 0, 0);
+  label = gtk_label_new (N_("Host"));
+  gtk_table_attach (GTK_TABLE(table1), label, 0, 1, 1, 2,
+                   GTK_FILL, GTK_FILL, 0, 0);
+  label = gtk_label_new (N_("Value"));
+  gtk_table_attach (GTK_TABLE(table1), label, 0, 1, 2, 3,
+                   GTK_FILL, GTK_FILL, 0, 0);
+  get_panel->entries[SET_MIB_ENTRY] = gtk_entry_new ();
+  gtk_table_attach (GTK_TABLE (table1), get_panel->entries[SET_MIB_ENTRY],
+		    1, 4, 0, 1,
+		    GTK_FILL, GTK_FILL, 2, 2);
+  get_panel->entries[SET_MIB_HOST] = gtk_combo_new ();
+  gtk_table_attach (GTK_TABLE (table1), get_panel->entries[SET_MIB_HOST],
+		    1, 4, 1, 2,
+		    GTK_FILL, GTK_FILL, 2, 2);
+  get_panel->entries[SET_MIB_RESULT] = gtk_entry_new ();
+  gtk_table_attach (GTK_TABLE (table1), get_panel->entries[SET_MIB_RESULT],
+		    1, 4, 2, 3,
+		    GTK_FILL, GTK_FILL, 2, 2);
+  hseparator1 = gtk_hseparator_new();
+  gtk_table_attach(GTK_TABLE(table1), hseparator1, 0, 4, 3, 4,
+                   GTK_FILL, GTK_FILL, 1, 1);
+  frame2 = gtk_frame_new(NULL);
+  gtk_table_attach(GTK_TABLE(table1), frame2, 0, 4, 4, 5,
+                   GTK_FILL, GTK_FILL, 0, 0);
+  gtk_container_border_width (GTK_CONTAINER(frame2), 4);
+  hbuttonbox1 = gtk_hbutton_box_new();
+  gtk_container_add (GTK_CONTAINER (frame2), hbuttonbox1);
+  gtk_container_border_width (GTK_CONTAINER (hbuttonbox1), 4);
+
+  get_panel->buttons[SET_QUERY_BUTTON] = gtk_button_new_with_label 
+    (N_("Query"));
+  gtk_container_add (GTK_CONTAINER (hbuttonbox1), 
+		     get_panel->buttons[SET_QUERY_BUTTON]);
+  get_panel->buttons[SET_CLEAR_BUTTON] = gtk_button_new_with_label
+    (N_("Clear"));
+  gtk_container_add (GTK_CONTAINER (hbuttonbox1),
+		     get_panel->buttons[SET_CLEAR_BUTTON]);
+  get_panel->buttons[SET_CLOSE_BUTTON] = gnome_stock_button
+    (GNOME_STOCK_BUTTON_CLOSE);
+  gtk_signal_connect (GTK_OBJECT (get_panel->buttons[SET_CLOSE_BUTTON]),
+		      "clicked",
+		      (GtkSignalFunc) close_get_panel_cb,
+		      get_panel->window);
+  gtk_container_add (GTK_CONTAINER (hbuttonbox1), 
+		     get_panel->buttons[SET_CLOSE_BUTTON]);
+  gnome_app_set_contents (GNOME_APP (get_panel->window), frame1);
+  gtk_widget_show_all (get_panel->window);
 }
 
 /*
@@ -931,6 +1025,7 @@ create_get_panel ()
 static gint
 delete_get_panel (GtkWidget *widget, GdkEvent *e, gpointer data)
 {
+  destroy_get_panel ();
 }
 
 static void
@@ -958,7 +1053,11 @@ void
 destroy_get_panel ()
 {
   if (get_panel)
-    delete_get_panel (NULL, NULL, get_panel);
+    {
+      gtk_widget_destroy (get_panel->window);
+      g_free (get_panel);
+      get_panel = NULL;
+    }
 }
 
 void 
