@@ -162,7 +162,7 @@ sprint_octet_string(char *buf, int buflen, SNMP_OBJECT *var,
       return;
     }
   hex = 0;
-  for(cp = var->syntax.bufchr, x = 0; x < var->syntax_len; x++, cp++)
+  for(cp = var->syntax.string, x = 0; x < var->syntax_len; x++, cp++)
     {
       if (!(isprint(*cp) || isspace(*cp)))
         hex = 1;
@@ -180,7 +180,7 @@ sprint_octet_string(char *buf, int buflen, SNMP_OBJECT *var,
           *buf++ = '"';
           buflen --;
         }
-      sprint_asciistring(buf, buflen, var->syntax.bufchr, var->syntax_len);
+      sprint_asciistring(buf, buflen, var->syntax.string, var->syntax_len);
       buflen -= strlen(buf);
       buf += strlen(buf);
       if (buflen)
@@ -192,7 +192,7 @@ sprint_octet_string(char *buf, int buflen, SNMP_OBJECT *var,
     }
   if (hex || var->syntax_len <= 4)
     {
-      sprint_hexstring(buf, buflen, var->syntax.bufchr, var->syntax_len);
+      sprint_hexstring(buf, buflen, var->syntax.string, var->syntax_len);
     }
 }
 
@@ -209,7 +209,7 @@ sprint_opaque(char *buf, int buflen, SNMP_OBJECT *var,
       sprint_by_type(buf, buflen, var, (struct enum_list *)NULL);
       return;
     }
-  sprint_hexstring(buf, buflen, var->syntax.bufchr, var->syntax_len);
+  sprint_hexstring(buf, buflen, var->syntax.string, var->syntax_len);
 }
 
 static void
@@ -224,7 +224,7 @@ sprint_object_identifier(char *buf, int buflen, SNMP_OBJECT *var,
       sprint_by_type(buf, buflen, var, (struct enum_list *)NULL);
       return;
     }
-  sprint_objid(buf, buflen, (gulong *)var->syntax.bufint, 
+  sprint_objid(buf, buflen, (gulong *)var->syntax.oid, 
                var->syntax_len / sizeof(gulong));
 }
 
@@ -337,7 +337,7 @@ sprint_networkaddress(char *buf, int buflen, SNMP_OBJECT *var,
 
   sprintf(buf, "Network Address: ");
   buf += strlen(buf);
-  cp = var->syntax.bufchr;    
+  cp = var->syntax.string;    
   len = var->syntax_len;
   for(x = 0; x < len; x++)
     {
@@ -362,7 +362,7 @@ sprint_ipaddress(char *buf, int buflen, SNMP_OBJECT *var,
       sprint_by_type(buf, buflen, var, (struct enum_list *)NULL);
       return;
     }
-    ip = var->syntax.bufchr;
+    ip = var->syntax.string;
     sprintf(buf, "IpAddress: %d.%d.%d.%d",ip[0], ip[1], ip[2], ip[3]);
 }
 
@@ -399,10 +399,10 @@ sprint_bitstring(char *buf, int buflen, SNMP_OBJECT *var,
     }
   sprintf(buf, "BIT_STRING: ");
   buf += strlen(buf);
-  sprint_hexstring(buf, buflen, var->syntax.bufchr, var->syntax_len);
+  sprint_hexstring(buf, buflen, var->syntax.string, var->syntax_len);
   buf += strlen(buf);
 
-  cp = var->syntax.bufchr + 1;
+  cp = var->syntax.string + 1;
   for(len = 0; len < var->syntax_len - 1; len++)
     {
       for(bit = 0; bit < 8; bit++)
@@ -441,7 +441,7 @@ sprint_nsapaddress(char *buf, int buflen, SNMP_OBJECT *var,
     }
   sprintf(buf, "NsapAddress: ");
   buf += strlen(buf);
-  sprint_hexstring(buf, buflen, var->syntax.bufchr, var->syntax_len);
+  sprint_hexstring(buf, buflen, var->syntax.string, var->syntax_len);
 }
 
 static void
@@ -459,9 +459,9 @@ sprint_counter64(char *buf, int buflen, SNMP_OBJECT *var,
   sprintf(buf, "Counter64: ");
   buf += strlen(buf);
     
-  sprint_hexstring(buf, buflen, &(var->syntax.bufchr[0]), 4);
+  sprint_hexstring(buf, buflen, &(var->syntax.string[0]), 4);
   buf += strlen(buf);
-  sprint_hexstring(buf, buflen, &(var->syntax.bufchr[4]), 4);
+  sprint_hexstring(buf, buflen, &(var->syntax.string[4]), 4);
 }
 
 
