@@ -19,8 +19,6 @@
 
     ---------------------------------------------------------------------- */
 
-#include <config.h>
-
 #include <sys/stat.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -47,7 +45,6 @@
 #define LOG_COL7                 400
 #define LOG_TITLEY               10
 
-#define MAX_NUM_LOGS             10
 #define MAX_NUM_DPY_LINES        300
 #define MAX_DPY_NUM_CHARS        200
 #define DEF_NUM_LOGS             1
@@ -56,6 +53,14 @@
 #define FRMT_NORMAL              2
 
 
+/* Global variables */
+
+extern int loginfovisible, calendarvisible;
+extern int zoom_visible;
+extern ConfigData *cfg;
+extern GtkWidget *main_win_scrollbar;
+extern GtkLabel *filename_label, *date_label;
+
 
 /*
  * -------------------
@@ -71,7 +76,7 @@ Log *loglist[MAX_NUM_LOGS];
 Log *curlog;
 int numlogs, curlognum;
 int log_line_sep;
-int open_log_visible;
+int cursor_visible;
 char *deflognames[] =
 {"/var/log/messages"};
 
@@ -79,9 +84,7 @@ char *month[12] =
 {"January", "February", "March", "April", "May",
  "June", "July", "August", "September", "October",
  "November", "December"};
-
-extern int loginfovisible, calendarvisible;
-extern ConfigData *cfg;
+extern GtkWidget *main_win_scrollbar;
 
 /*
  * -------------------
@@ -94,9 +97,10 @@ int HandleLogEvents ();
 int GetLineAtCursor (int y);
 int RepaintCalendar (GtkWidget * widget, GdkEventExpose * event);
 int RepaintLogInfo (GtkWidget *, GdkEventExpose *);
-void log_repaint (GtkWidget * cv, GdkRectangle * area);
+int rapaint_zoom (GtkWidget * widget, GdkEventExpose * event);
+void log_repaint (GtkWidget * cv, GdkEventExpose * event);
 void log_redrawcursor (int ol, int nl, Page * np);
-void log_redrawdetail (Page * pg, int ln);
+void log_redrawdetail ();
 void ShowErrMessage (char *msg);
 void DrawMonthHeader (LogLine * line, int y);
 void DrawLogLine (LogLine *line, int y);
@@ -104,10 +108,16 @@ void DrawLogCursor (int y);
 void EraseLogCursor (int y);
 void Draw3DBox (GdkDrawable *win, GdkGC *gc, int x, int y, int w, int h, GdkColor color[3]);
 void CloseApp ();
+void UpdateStatusArea ();
 void InitCalendarData ();
+void ScrollUp (int howmuch);
+void ScrollDown (int howmuch);
+void change_log (int direction);
+void create_zoom_view (GtkWidget * widget, gpointer user_data);
+void close_zoom_view (GtkWidget * widget, GtkWindow ** window);
+void handle_log_mouse_button (GtkWidget * win, GdkEventButton * event_key);
 Page *GetPageAtCursor (int y);
 
-
 /* ----------------------------------------------------------------------
    NAME:        PointerMoved
    DESCRIPTION: The pointer moved inside the window.
@@ -124,13 +134,14 @@ PointerMoved (GtkWidget * cv, GdkEventMotion * event)
       return;
 
    cursory = event->y;
+   cursor_visible = TRUE;
    if ((nl = GetLineAtCursor (cursory)) != -1 && nl != curlog->pointerln)
    {
       np = GetPageAtCursor (cursory);
-      log_redrawdetail (np, nl);
       log_redrawcursor (curlog->pointerln, nl, np);
       curlog->pointerln = nl;
       curlog->pointerpg = np;
+      log_redrawdetail ();
    }
 }
 
@@ -170,6 +181,35 @@ NumTextLines (int l)
    return ((ln - curlog->firstline));
 }
 
+/* ----------------------------------------------------------------------
+   NAME:        handle_log_mouse_button
+   DESCRIPTION: User clicked on main window: open zoom view. 
+   ---------------------------------------------------------------------- */
+
+void
+handle_log_mouse_button (GtkWidget * win, GdkEventButton *event)
+{
+  static guint32 lasttime;
+  static int clicked_before = FALSE;
+
+  if (event->type == GDK_BUTTON_PRESS && !clicked_before)
+    {
+      lasttime = event->time;
+      clicked_before = TRUE;
+      return;
+    }
+  
+  clicked_before = FALSE;
+  if (event->time - lasttime < 100 ||
+      event->time - lasttime > 200)
+    return;
+
+  /* If zoom is already visible ignore */
+  if (!zoom_visible)
+    create_zoom_view (NULL, NULL);
+  return;
+}
+
 /* ----------------------------------------------------------------------
    NAME:        HandleLogKeyboard
    DESCRIPTION: Handle all posible keyboard actions.
@@ -178,217 +218,165 @@ NumTextLines (int l)
 void
 HandleLogKeyboard (GtkWidget * win, GdkEventKey * event_key)
 {
-   int ln, nl, y;
-   guint key;
-   Page *next;
+  GtkAdjustment *adj;
+  int ln, y;
+  DateMark *mark;
+  guint key;
 
-   /* Check that there is at least one log */
-   if (curlog == NULL)
-      return;
-
-   key = event_key->keyval;
-   switch (key)
-   {
-   case GDK_R:
-   case GDK_r:
-      curlog->firstline = 0;
-      log_repaint (win, NULL);
-      break;
-   case GDK_Q:
-   case GDK_q:
+  /* Check that there is at least one log */
+  if (curlog == NULL)
+    return;
+  
+  adj = GTK_ADJUSTMENT (GTK_RANGE (main_win_scrollbar)->adjustment);
+  key = event_key->keyval;
+  cursor_visible = FALSE;
+  switch (key)
+    {
+    case GDK_Q:
+    case GDK_q:
       CloseApp ();
       break;
-
-   case GDK_plus:
-      if (numlogs == 1)
-	 return;
-      if (curlognum == numlogs - 1)
-	 curlognum = 0;
-      else
-	 curlognum++;
-      curlog = loglist[curlognum];
-      log_repaint (win, NULL);
-      if (loginfovisible)
-	 RepaintLogInfo (NULL, NULL);
-      if (calendarvisible)
-      {
-	 InitCalendarData ();
-	 RepaintCalendar (NULL, NULL);
-      }
+      
+    case GDK_plus:
+      change_log(1);
+      break;
+      
+    case GDK_minus:
+      change_log(-1);
+      break;
+      
+     case GDK_Page_Up: 
+     case GDK_KP_Page_Up: 
+     case GDK_R9: 
+       cursor_visible = FALSE;
+       gtk_adjustment_set_value (adj, (adj->value - (float) (LINES_P_PAGE >> 1)));
       break;
 
-   case GDK_minus:
-      if (numlogs == 1)
-	 return;
-      if (curlognum == 0)
-	 curlognum = numlogs - 1;
-      else
-	 curlognum--;
-      curlog = loglist[curlognum];
-      log_repaint (win, NULL);
-      if (loginfovisible)
-	 RepaintLogInfo (NULL, NULL);
-      if (calendarvisible)
-      {
-	 InitCalendarData ();
-	 RepaintCalendar (NULL, NULL);
-      }
+    case GDK_Up:
+      cursor_visible = FALSE;
+      gtk_adjustment_set_value (adj, (adj->value - 1.0));
       break;
-
-   case GDK_Page_Up:
-   case GDK_KP_Page_Up:
-   case GDK_R9:
-   case GDK_Up:
-      ln = curlog->firstline;
-      ln -= (key == GDK_Up) ? 1 : NumTextLines ((LINES_P_PAGE >> 1));
-      if (curlog->currentpg->isfirstpage == TRUE)
-      {
-	 if (ln < 0)
-	    ln = 0;
-	 curlog->firstline = ln < curlog->currentpg->fl ? curlog->currentpg->fl : ln;
-	 log_repaint (win, NULL);
-	 break;
-      }
-      if (ln < 0)
-      {
-	 ln += LINES_P_PAGE;
-	 next = curlog->currentpg->prev;
-	 if (next == curlog->firstpg)
-	    ReadNPagesUp (curlog, next, (NUM_PAGES>>1));
-	 if (curlog->currentpg->isfirstpage == FALSE)
-	    curlog->currentpg = curlog->currentpg->prev;
-      }
-      if (curlog->currentpg->isfirstpage == TRUE)
-	 curlog->firstline = MAX (ln, curlog->currentpg->fl);
-      else
-	 curlog->firstline = ln;
-      if ((nl = GetLineAtCursor (y)) != -1)
-      {
-	 curlog->pointerln = nl;
-	 curlog->pointerpg = GetPageAtCursor (y);
-      }
-      log_repaint (win, NULL);
+      
+    case GDK_Page_Down:
+    case GDK_KP_Page_Down:
+    case GDK_R15:
+      cursor_visible = FALSE;
+      gtk_adjustment_set_value (adj, (adj->value + (float) (LINES_P_PAGE >> 1)));
       break;
-
-   case GDK_Page_Down:
-   case GDK_KP_Page_Down:
-   case GDK_R15:
-   case GDK_Down:
-      if (curlog->currentpg->islastpage == TRUE)
-	 break;
-      ln = curlog->firstline;
-      ln += (key == GDK_Down) ? 1 : NumTextLines ((LINES_P_PAGE >> 1));
-      if (ln >= LINES_P_PAGE)
-      {
-	 ln -= LINES_P_PAGE;
-	 next = curlog->currentpg->next;
-	 if (next == curlog->lastpg)
-	    ReadNPagesDown (curlog, next, (NUM_PAGES>>1));
-	 curlog->currentpg = curlog->currentpg->next;
-      }
-      curlog->firstline = ln;
-      if ((nl = GetLineAtCursor (y)) != -1)
-      {
-	 curlog->pointerln = nl;
-	 curlog->pointerpg = GetPageAtCursor (y);
-      }
-      log_repaint (win, NULL);
+    case GDK_Down:
+      cursor_visible = FALSE;
+      gtk_adjustment_set_value (adj, (adj->value + 1.0));
       break;
-
-   default:
+      
+    default:
       break;
-   };
-
+    };
+  
    return;
 }
 
 /* ----------------------------------------------------------------------
-   NAME:          FileSelectCancel
-   DESCRIPTION:   User selected a file.
+   NAME:        change_log
+   DESCRIPTION: 
    ---------------------------------------------------------------------- */
 
 void
-FileSelectCancel (GtkWidget * w, GtkFileSelection * fs)
+change_log (int direction)
 {
-   gtk_widget_destroy (GTK_WIDGET (fs));
-   open_log_visible = FALSE;
+  if (numlogs == 1)
+    return;
+  if (direction > 0)
+    {
+      if (curlognum == numlogs - 1)
+	curlognum = 0;
+      else
+	curlognum++;
+    }
+  else      
+    {
+      if (curlognum == 0)
+	curlognum = numlogs - 1;
+      else
+	curlognum--;
+    }
+
+  curlog = loglist[curlognum];
+  set_scrollbar_size (curlog->lstats.numlines);
+  gtk_adjustment_set_value ( GTK_RANGE(main_win_scrollbar)->adjustment, 
+			     curlog->ln);
+  log_repaint (NULL, NULL);
+  if (loginfovisible)
+    RepaintLogInfo (NULL, NULL);
+  if (calendarvisible)
+    {
+      InitCalendarData ();
+      RepaintCalendar (NULL, NULL);
+    }
+  UpdateStatusArea();
 }
 
 /* ----------------------------------------------------------------------
-   NAME:          FileSelectOk
-   DESCRIPTION:   User selected a file.
+   NAME:        ScrollDown
+   DESCRIPTION: Scroll the main window down.
    ---------------------------------------------------------------------- */
 
 void
-FileSelectOk (GtkWidget * w, GtkFileSelection * fs)
+ScrollDown (int howmuch)
 {
-   char *f;
-   Log *tl;
-
-   /* Check that we haven't opened all logfiles allowed    */
-   if (numlogs >= MAX_NUM_LOGS)
-     {
-       ShowErrMessage ("Too many open logs. Close one and try again");
-       return;
-     }
-
-   f = gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs));
-   gtk_widget_destroy (GTK_WIDGET (fs));
-   open_log_visible = FALSE;
-   if (f != NULL)
-      if ((tl = OpenLogFile (f)) != NULL)
-      {
-	 curlog = tl;
-	 loglist[numlogs] = tl;
-	 numlogs++;
-	 curlognum = numlogs - 1;
-	 if (loginfovisible)
-	    RepaintLogInfo (NULL, NULL);
-	 if (calendarvisible)
-	   {
-	     InitCalendarData();
-	     RepaintCalendar (NULL, NULL);
-	   }
-      }
+  int ln;
+  Page *next;
 
+  ln = curlog->firstline;
+  ln += howmuch;
+  while (ln >= LINES_P_PAGE && !curlog->currentpg->islastpage )
+    {
+      ln -= LINES_P_PAGE;
+      next = curlog->currentpg->next;
+      if (next == curlog->lastpg)
+	ReadNPagesDown (curlog, next, (NUM_PAGES>>1));
+      curlog->currentpg = curlog->currentpg->next;
+    }
+  curlog->firstline = ln;
 }
 
 /* ----------------------------------------------------------------------
-   NAME:          LoadLogMenu
-   DESCRIPTION:   Open a new log defined by the user.
+   NAME:        ScrollUp
+   DESCRIPTION: Scroll the main window up.
    ---------------------------------------------------------------------- */
 
 void
-LoadLogMenu (GtkWidget * widget, gpointer user_data)
+ScrollUp (int howmuch)
 {
-   GtkWidget *filesel = NULL;
+  int ln;
+  Page *next;
 
-   /*  Cannot open more than MAX_NUM_LOGS */
-   if (numlogs == MAX_NUM_LOGS)
+  ln = curlog->firstline;
+  ln -= howmuch;
+
+  if (curlog->currentpg->isfirstpage == TRUE && !curlog->currentpg->isfirstpage)
+    {
+      if (ln < 0)
+	ln = 0;
+      curlog->firstline = ln < curlog->currentpg->fl ? curlog->currentpg->fl : ln;
       return;
-   
-   /*  Cannot have more than one fileselect window */
-   /*  at one time. */
-   if (open_log_visible)
-     return;
+    }
+
+  while (ln < 0)
+    {
+      ln += LINES_P_PAGE;
+      next = curlog->currentpg->prev;
+      if (next == curlog->firstpg)
+	ReadNPagesUp (curlog, next, (NUM_PAGES>>1));
+      if (curlog->currentpg->isfirstpage == FALSE)
+	curlog->currentpg = curlog->currentpg->prev;
+    }
+  if (curlog->currentpg->isfirstpage == TRUE)
+    curlog->firstline = MAX (ln, curlog->currentpg->fl);
+  else
+    curlog->firstline = ln;
 
 
-   filesel = gtk_file_selection_new ("Open new logfile");
-   gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel), PATH_MESSAGES);
-   gtk_window_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
-   gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
-		       "clicked", (GtkSignalFunc) FileSelectOk,
-		       filesel);
-   gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
-			      "clicked", (GtkSignalFunc) FileSelectCancel,
-			      GTK_OBJECT (filesel));
-
-   if (!GTK_WIDGET_VISIBLE (filesel))
-      gtk_widget_show (filesel);
-   else
-      gtk_widget_destroy (filesel);
-
-   open_log_visible = TRUE;
+  return;
 }
 
 /* ----------------------------------------------------------------------
@@ -397,12 +385,13 @@ LoadLogMenu (GtkWidget * widget, gpointer user_data)
    ---------------------------------------------------------------------- */
 
 void
-log_repaint (GtkWidget * win, GdkRectangle * area)
+log_repaint (GtkWidget * win, GdkEventExpose * event)
 {
    static int firsttime = TRUE;
    int ln, y, cm, cd, offset;
    Page *pg;
    LogLine *line;
+   GdkRectangle *area;
 
    if (firsttime)
    {
@@ -415,8 +404,16 @@ log_repaint (GtkWidget * win, GdkRectangle * area)
    }
    offset = LOG_TITLEY;
 
+   area = NULL;
+   if (event != NULL)
+       area = &event->area;
+
    /* Erase page */
-   gdk_window_clear (canvas);
+   if (area != NULL)
+     gdk_window_clear_area (canvas, area->x, area->y, 
+			    area->width, area->height);
+   else
+     gdk_window_clear (canvas);
 
    /* Check that there is at least one log */
    if (curlog == NULL)
@@ -427,7 +424,7 @@ log_repaint (GtkWidget * win, GdkRectangle * area)
    cm = cd = -1;
    y = offset;
 
-   log_redrawdetail (curlog->pointerpg, curlog->pointerln);
+   log_redrawdetail ();
 
    while ((y - offset) < LOG_CANVAS_H)
    {
@@ -440,7 +437,7 @@ log_repaint (GtkWidget * win, GdkRectangle * area)
 	 cd = line->date;
 	 y += 2 * log_line_sep;
       }
-      if (ln == curlog->pointerln && pg == curlog->pointerpg)
+      if (ln == curlog->pointerln && pg == curlog->pointerpg && cursor_visible)
 	 DrawLogCursor (y);
 
       DrawLogLine (line, y);
@@ -448,7 +445,7 @@ log_repaint (GtkWidget * win, GdkRectangle * area)
       ln++;
       if (ln > pg->ll && pg->islastpage == TRUE)
 	 break;
-      if (ln >= LINES_P_PAGE)
+      if (ln > LINES_P_PAGE-1)
       {
 	 if (pg->islastpage == FALSE)
 	    pg = pg->next;
@@ -458,6 +455,36 @@ log_repaint (GtkWidget * win, GdkRectangle * area)
       }
    }
 
+  /* Repaint status bar */
+   UpdateStatusArea ();
+}
+
+void
+UpdateStatusArea ()
+{
+  struct tm *tdm;
+  char status_text[255];
+  char *buffer;
+
+  if (curlog == NULL)
+    return;
+
+  if (curlog->name != NULL)
+    {
+      strncpy (status_text, curlog->name, 30);
+      gtk_label_get ( filename_label, (char **)&buffer);
+      if (strcmp (status_text, buffer) != 0)
+	gtk_label_set (filename_label, status_text);
+    }
+
+  tdm = &curlog->curmark->fulldate;
+  sprintf (status_text, "%02d/%02d/%02d", 
+	   tdm->tm_mday, tdm->tm_mon, tdm->tm_year);
+  gtk_label_get ( date_label, (char **)&buffer);
+  if (strcmp (status_text, buffer) != 0)
+    gtk_label_set (date_label, status_text);
+
+  return;
 }
 
 /* ----------------------------------------------------------------------
@@ -492,7 +519,7 @@ log_redrawcursor (int ol, int nl, Page * np)
       }
       if ((ln == ol && pg == op) || (ln == nl && pg == np))
       {
-	 if (ln == nl)
+	 if (ln == nl && cursor_visible)
 	    DrawLogCursor (y);
 	 else
 	    EraseLogCursor (y);
@@ -525,6 +552,7 @@ DrawLogLine (LogLine *line, int y)
 {
    char tmp[90];
 
+   /*gdk_gc_set_foreground (gc, &cfg->white); */
    gdk_gc_set_foreground (gc, &cfg->black);
 
    if (line->hour >= 0 && line->min >= 0 && line->sec >= 0)
@@ -625,8 +653,10 @@ EraseLogCursor (int y)
    ---------------------------------------------------------------------- */
 
 void
-log_redrawdetail (Page * pg, int ln)
+log_redrawdetail ()
 {
+  if (zoom_visible)
+    repaint_zoom (NULL, NULL);
 }
 
 /* ----------------------------------------------------------------------
