@@ -919,6 +919,9 @@ GetDate (char *line)
    int i;
 
    token = strtok (line, " ");
+   if (!token)
+       return -1;
+   
    for (i = 0; i < 12; i++)
       if (strncasecmp (token, monthname[i], 3) == 0)
 	 break;
