@@ -358,7 +358,7 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
    GtkWidget *frame;
    GtkWidget *vbox;
    GtkWidget *tmpwidget;
-   GtkWidget *scrolled_win;
+   GtkCList *clist;
    GList *tmplist;
    char logfile[256];
    int i,lnum,x,y,w,h;
@@ -371,7 +371,10 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
      {
      lnum = atoi(gtk_widget_get_name(tmplist->data));
      if (loglist[lnum] != NULL)
-       loglist[lnum]->mon_on = TRUE;
+       {
+	 i++;
+	 loglist[lnum]->mon_on = TRUE;
+       }
      tmplist = tmplist->next;
      }
 
@@ -386,17 +389,22 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
      }
    
 
+   /* Open window only if at least one log is selected */
+   if (i == 0)
+     return;
+
    /* Create monitor window */
    /* setup size */
    w = 600; h = 100;
    x = gdk_screen_width () - w - 2;
    y = gdk_screen_height ()- h - 2;
 
-   monwindow = gtk_window_new (GTK_WINDOW_POPUP); /*  Window without borders! */
-   /* monwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);  */
+   /* monwindow = gtk_window_new (GTK_WINDOW_POPUP);  */ /*  Window without borders! */
+   monwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_border_width (GTK_CONTAINER (monwindow), 0);
    gtk_window_set_title (GTK_WINDOW (monwindow), "Monitoring logs..");
    gtk_widget_set_style (monwindow, cfg->main_style);
+
    gtk_widget_set_usize(monwindow, w, h);
    gtk_widget_set_uposition(monwindow, x, y);
    gtk_signal_connect (GTK_OBJECT (monwindow), "destroy",
@@ -428,22 +436,18 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
        gtk_widget_show (frame);
        
        /* Create destination list */
-       scrolled_win = gtk_scrolled_window_new (NULL, NULL);
-       loglist[i]->monwin = (GtkScrolledWindow *)scrolled_win;
-       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
-				       GTK_POLICY_AUTOMATIC, 
-				       GTK_POLICY_AUTOMATIC);
-       gtk_range_set_update_policy (GTK_RANGE(GTK_SCROLLED_WINDOW(scrolled_win)->vscrollbar), GTK_UPDATE_CONTINUOUS );
-       gtk_widget_set_style (scrolled_win, cfg->main_style);
-       gtk_container_add (GTK_CONTAINER (frame), scrolled_win);
-       gtk_widget_show (scrolled_win);
-       
-       tmpwidget = gtk_list_new ();
-       gtk_container_add (GTK_CONTAINER (scrolled_win), tmpwidget);
-       gtk_widget_set_style (tmpwidget, cfg->main_style);
-       gtk_widget_show (tmpwidget);
-       
-       loglist[i]->list = (GtkList *)tmpwidget;
+       clist = (GtkCList *)gtk_clist_new (1);
+       gtk_clist_set_column_width (clist, 0, 500);
+       gtk_clist_set_selection_mode (clist, GTK_SELECTION_BROWSE);
+       gtk_clist_set_policy (clist,
+			     GTK_POLICY_AUTOMATIC,
+			     GTK_POLICY_AUTOMATIC);
+
+       gtk_clist_set_column_justification (clist, 0, GTK_JUSTIFY_LEFT); 
+       gtk_widget_set_style (GTK_WIDGET (clist), cfg->main_style);
+       loglist[i]->mon_lines = (GtkCList *) clist;
+       gtk_container_add (GTK_CONTAINER (frame), GTK_WIDGET (clist));
+       gtk_widget_show (GTK_WIDGET (clist));
        
        mon_read_last_page (loglist[i]);
        label = gtk_label_new (logfile);
@@ -468,31 +472,35 @@ void
 mon_read_last_page (Log *log)
 {
   Page pg;
-  GtkWidget *list_item;
   char buffer[500];
-  int i;
+  gchar *texts[2];
+  int i, j;
 
   log->mon_numlines = 0;
   fseek (log->fp, log->offset_end, SEEK_SET);
   
   /* Read pages into buffers --------------------------- */
   ReadPageUp (log, &pg);
+  
+  texts[0] = buffer;
+  texts[1] = NULL;
 
   for (i=pg.ll-5;i<pg.ll;i++)
     {
       if (i<0)
 	continue;
       mon_format_line (buffer, &pg.line[i]);
-      list_item = gtk_list_item_new_with_label(buffer);
-      gtk_container_add (GTK_CONTAINER (log->list), list_item);
-      gtk_widget_set_style (list_item, cfg->main_style);
-      gtk_widget_show (list_item);
+      gtk_clist_append (log->mon_lines, texts);
       log->mon_numlines++;
       if (log->mon_numlines > MON_MAX_NUM_LINES)
 	{
-	  gtk_list_clear_items (log->list,0,LINES_P_PAGE);
+	  gtk_clist_freeze (log->mon_lines);
+	  for(j=0;j<LINES_P_PAGE;j++)
+	    gtk_clist_remove (log->mon_lines, j);
 	  log->mon_numlines -= LINES_P_PAGE;
+	  gtk_clist_thaw (log->mon_lines);
 	}
+      gtk_clist_moveto (log->mon_lines, log->mon_numlines, -1,0,0);
     }
 }
 
@@ -505,31 +513,34 @@ void
 mon_read_new_lines (Log *log)
 {
   Page pg;
-  GtkWidget *list_item;
   char buffer[500];
-  int i;
+  gchar *texts[2];
+  int i,j;
 
   fseek (log->fp, log->offset_end, SEEK_SET);
   
   /* Read pages into buffers --------------------------- */
   ReadPageDown (log, &pg);
+  texts[0] = buffer;
+  texts[1] = NULL;
+
   while (TRUE) 
     {
       for (i=pg.fl;i<pg.ll;i++)
 	{
 	  mon_format_line (buffer, &pg.line[i]);
-	  list_item = gtk_list_item_new_with_label(buffer);
-	  gtk_container_add (GTK_CONTAINER (log->list), list_item);
-	  gtk_widget_show (list_item);
-	  /*   gtk_list_select_child (log->list, list_item); */
+	  gtk_clist_append (log->mon_lines, texts);
 	  log->mon_numlines++;
-	  gtk_range_default_vmotion (GTK_RANGE(log->monwin->vscrollbar), 0, 64);
 	} 
       if (log->mon_numlines > MON_MAX_NUM_LINES)
 	{
-	  gtk_list_clear_items (log->list,0,LINES_P_PAGE);
+	  gtk_clist_freeze (log->mon_lines);
+	  for(j=0;j<LINES_P_PAGE;j++)
+	    gtk_clist_remove (log->mon_lines, j);
 	  log->mon_numlines -= LINES_P_PAGE;
+	  gtk_clist_thaw (log->mon_lines);
 	}
+      gtk_clist_moveto (log->mon_lines, log->mon_numlines, -1,0,0);
       if (pg.islastpage)
 	break;
       ReadPageDown (log, &pg);
